/*
 * drive-check.h
 *
 * Written by
 *  Andreas Boose <viceteam@t-online.de>
 *
 * This file is part of VICE, the Versatile Commodore Emulator.
 * See README for copyright notice.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307  USA.
 *
 */

#ifndef VICE_DRIVE_CHECK_H
#define VICE_DRIVE_CHECK_H

extern unsigned int drive_check_bus(unsigned int drive_type, unsigned int bus_map);
extern unsigned int drive_check_old(unsigned int type);
extern unsigned int drive_check_dual(unsigned int type);

extern unsigned int drive_get_num_heads(unsigned int type);
extern unsigned int drive_get_half_tracks(unsigned int type);

#endif
